@@ -62,6 +62,7 @@ import signal
 import os.path
 import shutil
 import stat
+import codecs
 
 
 # do not run as module
@@ -85,8 +86,8 @@ against. Please run GNUmed as a non-root user.
 	sys.exit(1)
 
 #----------------------------------------------------------
-current_client_version = u'1.3.9'
-current_client_branch = u'1.3'
+current_client_version = u'1.4.1'
+current_client_branch = u'1.4'
 
 _log = None
 _cfg = None
@@ -171,13 +172,10 @@ def setup_python_path():
 	if not u'--local-import' in sys.argv:
 		return
 
-	print "Running from local source tree ..."
-
 	local_python_base_dir = os.path.dirname (
 		os.path.abspath(os.path.join(sys.argv[0], '..'))
 	)
-
-	print ' (%s)' % local_python_base_dir
+	print "Running from local source tree (%s) ..." % local_python_base_dir
 
 	# does the path exist at all, physically ?
 	# (*broken* links are reported as False)
@@ -243,7 +241,7 @@ def setup_local_repo_path():
 			_log.error('insecure repo: permissions not 0600')
 			return
 
-	print "Activating local wxGlade widgets repository ..."
+	print "Activating local wxGlade widgets repository (%s) ..." % local_wxGladeWidgets_path
 	sys.path.insert(0, local_repo_path)
 	_log.debug('sys.path with repo:')
 	_log.debug(sys.path)
@@ -409,13 +407,36 @@ def handle_version_request():
 def setup_paths_and_files():
 	"""Create needed paths in user home directory."""
 
+	gnumed_DIR_README_TEXT = u"""GNUmed Electronic Medical Record
+
+	%s/
+
+This directory should only ever contain files which the
+user will come into direct contact with while using the
+application (say, by selecting a file from the file system,
+as when selecting document parts from files). You can create
+subdirectories here as you see fit for the purpose.
+
+This directory will also serve as the default directory when
+GNUmed asks the user to select a directory for storing a
+file.
+
+Any files which are NOT intended for direct user interaction
+but must be configured to live at a known location (say,
+inter-application data exchange files) should be put under
+the hidden directory "%s/".""" % (
+		os.path.expanduser(os.path.join('~', 'gnumed')),
+		os.path.expanduser(os.path.join('~', '.gnumed'))
+	)
+
 	gmTools.mkdir(os.path.expanduser(os.path.join('~', '.gnumed', 'scripts')))
 	gmTools.mkdir(os.path.expanduser(os.path.join('~', '.gnumed', 'spellcheck')))
-	gmTools.mkdir(os.path.expanduser(os.path.join('~', 'gnumed', 'export', 'docs')))
-	gmTools.mkdir(os.path.expanduser(os.path.join('~', 'gnumed', 'export', 'xDT')))
-	gmTools.mkdir(os.path.expanduser(os.path.join('~', 'gnumed', 'export', 'EMR')))
-	gmTools.mkdir(os.path.expanduser(os.path.join('~', 'gnumed', 'xDT')))
-	gmTools.mkdir(os.path.expanduser(os.path.join('~', 'gnumed', 'logs')))
+	gmTools.mkdir(os.path.expanduser(os.path.join('~', '.gnumed', 'error_logs')))
+	gmTools.mkdir(os.path.expanduser(os.path.join('~', 'gnumed')))
+
+	README = codecs.open(os.path.expanduser(os.path.join('~', 'gnumed', '00_README')), 'wb', 'utf8')
+	README.write(gnumed_DIR_README_TEXT)
+	README.close()
 
 	paths = gmTools.gmPaths(app_name = u'gnumed')
 
